jenkins-bot has submitted this change and it was merged.

Change subject: Changed some DatabaseBase type hints to IDatabase
......................................................................


Changed some DatabaseBase type hints to IDatabase

Change-Id: Id945aaabbf5b467106676ea9f3eab3a6161c7f3d
---
M includes/specials/SpecialActiveusers.php
M includes/specials/SpecialContributions.php
M includes/specials/SpecialDeletedContributions.php
M includes/specials/SpecialLinkSearch.php
M includes/specials/SpecialListDuplicatedFiles.php
M includes/specials/SpecialListredirects.php
M includes/specials/SpecialMediaStatistics.php
M includes/specials/SpecialMostcategories.php
M includes/specials/SpecialMostinterwikis.php
M includes/specials/SpecialMostlinked.php
M includes/specials/SpecialMostlinkedcategories.php
M includes/specials/SpecialMostlinkedtemplates.php
M includes/specials/SpecialShortpages.php
M includes/specials/SpecialUndelete.php
M includes/specials/SpecialWatchlist.php
15 files changed, 21 insertions(+), 21 deletions(-)

Approvals:
  KartikMistry: Looks good to me, but someone else must approve
  Chad: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/includes/specials/SpecialContributions.php 
b/includes/specials/SpecialContributions.php
index 59e2bba..1e829b1 100644
--- a/includes/specials/SpecialContributions.php
+++ b/includes/specials/SpecialContributions.php
@@ -658,7 +658,7 @@
        public $mDb;
        public $preventClickjacking = false;
 
-       /** @var DatabaseBase */
+       /** @var IDatabase */
        public $mDbSecondary;
 
        /**
diff --git a/includes/specials/SpecialDeletedContributions.php 
b/includes/specials/SpecialDeletedContributions.php
index e739a86..29c3fd4 100644
--- a/includes/specials/SpecialDeletedContributions.php
+++ b/includes/specials/SpecialDeletedContributions.php
@@ -266,7 +266,7 @@
        /**
         * Get the Database object in use
         *
-        * @return DatabaseBase
+        * @return IDatabase
         */
        public function getDatabase() {
                return $this->mDb;
diff --git a/includes/specials/SpecialLinkSearch.php 
b/includes/specials/SpecialLinkSearch.php
index 05c89c2..f6cb84d 100644
--- a/includes/specials/SpecialLinkSearch.php
+++ b/includes/specials/SpecialLinkSearch.php
@@ -254,7 +254,7 @@
        /**
         * Pre-fill the link cache
         *
-        * @param DatabaseBase $db
+        * @param IDatabase $db
         * @param ResultWrapper $res
         */
        function preprocessResults( $db, $res ) {
diff --git a/includes/specials/SpecialListDuplicatedFiles.php 
b/includes/specials/SpecialListDuplicatedFiles.php
index 2667270..1e3dff6 100644
--- a/includes/specials/SpecialListDuplicatedFiles.php
+++ b/includes/specials/SpecialListDuplicatedFiles.php
@@ -71,7 +71,7 @@
        /**
         * Pre-fill the link cache
         *
-        * @param DatabaseBase $db
+        * @param IDatabase $db
         * @param ResultWrapper $res
         */
        function preprocessResults( $db, $res ) {
diff --git a/includes/specials/SpecialListredirects.php 
b/includes/specials/SpecialListredirects.php
index de05be4..2df4834 100644
--- a/includes/specials/SpecialListredirects.php
+++ b/includes/specials/SpecialListredirects.php
@@ -72,7 +72,7 @@
        /**
         * Cache page existence for performance
         *
-        * @param DatabaseBase $db
+        * @param IDatabase $db
         * @param ResultWrapper $res
         */
        function preprocessResults( $db, $res ) {
diff --git a/includes/specials/SpecialMediaStatistics.php 
b/includes/specials/SpecialMediaStatistics.php
index 1084482..c26adc5 100644
--- a/includes/specials/SpecialMediaStatistics.php
+++ b/includes/specials/SpecialMediaStatistics.php
@@ -99,7 +99,7 @@
         *
         * @param $out OutputPage
         * @param $skin Skin (deprecated presumably)
-        * @param $dbr DatabaseBase
+        * @param $dbr IDatabase
         * @param $res ResultWrapper Results from query
         * @param $num integer Number of results
         * @param $offset integer Paging offset (Should always be 0 in our case)
@@ -314,7 +314,7 @@
        /**
         * Initialize total values so we can figure out percentages later.
         *
-        * @param $dbr DatabaseBase
+        * @param $dbr IDatabase
         * @param $res ResultWrapper
         */
        public function preprocessResults( $dbr, $res ) {
diff --git a/includes/specials/SpecialMostcategories.php 
b/includes/specials/SpecialMostcategories.php
index 9b67f34..c70bbdb 100644
--- a/includes/specials/SpecialMostcategories.php
+++ b/includes/specials/SpecialMostcategories.php
@@ -65,7 +65,7 @@
        }
 
        /**
-        * @param DatabaseBase $db
+        * @param IDatabase $db
         * @param ResultWrapper $res
         */
        function preprocessResults( $db, $res ) {
diff --git a/includes/specials/SpecialMostinterwikis.php 
b/includes/specials/SpecialMostinterwikis.php
index 30ccbe5..ab3d9c9 100644
--- a/includes/specials/SpecialMostinterwikis.php
+++ b/includes/specials/SpecialMostinterwikis.php
@@ -71,7 +71,7 @@
        /**
         * Pre-fill the link cache
         *
-        * @param DatabaseBase $db
+        * @param IDatabase $db
         * @param ResultWrapper $res
         */
        function preprocessResults( $db, $res ) {
diff --git a/includes/specials/SpecialMostlinked.php 
b/includes/specials/SpecialMostlinked.php
index 99f0ecf..ae0b070 100644
--- a/includes/specials/SpecialMostlinked.php
+++ b/includes/specials/SpecialMostlinked.php
@@ -74,7 +74,7 @@
        /**
         * Pre-fill the link cache
         *
-        * @param DatabaseBase $db
+        * @param IDatabase $db
         * @param ResultWrapper $res
         */
        function preprocessResults( $db, $res ) {
diff --git a/includes/specials/SpecialMostlinkedcategories.php 
b/includes/specials/SpecialMostlinkedcategories.php
index f61a115..cc718e0 100644
--- a/includes/specials/SpecialMostlinkedcategories.php
+++ b/includes/specials/SpecialMostlinkedcategories.php
@@ -55,7 +55,7 @@
        /**
         * Fetch user page links and cache their existence
         *
-        * @param DatabaseBase $db
+        * @param IDatabase $db
         * @param ResultWrapper $res
         */
        function preprocessResults( $db, $res ) {
diff --git a/includes/specials/SpecialMostlinkedtemplates.php 
b/includes/specials/SpecialMostlinkedtemplates.php
index 8e6a596..a924525 100644
--- a/includes/specials/SpecialMostlinkedtemplates.php
+++ b/includes/specials/SpecialMostlinkedtemplates.php
@@ -75,7 +75,7 @@
        /**
         * Pre-cache page existence to speed up link generation
         *
-        * @param DatabaseBase $db
+        * @param IDatabase $db
         * @param ResultWrapper $res
         */
        public function preprocessResults( $db, $res ) {
diff --git a/includes/specials/SpecialShortpages.php 
b/includes/specials/SpecialShortpages.php
index 782d9a1..7ec69e0 100644
--- a/includes/specials/SpecialShortpages.php
+++ b/includes/specials/SpecialShortpages.php
@@ -58,7 +58,7 @@
        }
 
        /**
-        * @param DatabaseBase $db
+        * @param IDatabase $db
         * @param ResultWrapper $res
         */
        function preprocessResults( $db, $res ) {
diff --git a/includes/specials/SpecialUndelete.php 
b/includes/specials/SpecialUndelete.php
index a1f48e9..bcf83c8 100644
--- a/includes/specials/SpecialUndelete.php
+++ b/includes/specials/SpecialUndelete.php
@@ -94,7 +94,7 @@
        }
 
        /**
-        * @param DatabaseBase $dbr
+        * @param IDatabase $dbr
         * @param string|array $condition
         * @return bool|ResultWrapper
         */
diff --git a/includes/specials/SpecialWatchlist.php 
b/includes/specials/SpecialWatchlist.php
index 421840f..ee4f486 100644
--- a/includes/specials/SpecialWatchlist.php
+++ b/includes/specials/SpecialWatchlist.php
@@ -300,9 +300,9 @@
        }
 
        /**
-        * Return a DatabaseBase object for reading
+        * Return a IDatabase object for reading
         *
-        * @return DatabaseBase
+        * @return IDatabase
         */
        protected function getDB() {
                return wfGetDB( DB_SLAVE, 'watchlist' );
@@ -607,7 +607,7 @@
        /**
         * Count the number of items on a user's watchlist
         *
-        * @param DatabaseBase $dbr A database connection
+        * @param IDatabase $dbr A database connection
         * @return int
         */
        protected function countItems( $dbr ) {

diff --git a/includes/specials/SpecialActiveusers.php 
b/includes/specials/SpecialActiveusers.php
index 6219fc4..fe06375 100644
--- a/includes/specials/SpecialActiveusers.php
+++ b/includes/specials/SpecialActiveusers.php
@@ -314,10 +314,10 @@
        }
 
        /**
         * @param DatabaseBase $dbw Passed in from updateSpecialPages.php
         * @return void
         */
-       public static function cacheUpdate( DatabaseBase $dbw ) {
+       public static function cacheUpdate( IDatabase $dbw ) {
                global $wgActiveUserDays;
 
                self::doQueryCacheUpdate( $dbw, $wgActiveUserDays, 
$wgActiveUserDays * 86400 );
@@ -326,12 +326,12 @@
        /**
         * Update the query cache as needed
         *
-        * @param DatabaseBase $dbw
+        * @param IDatabase $dbw
         * @param int $days How many days user must be idle before he is 
considered inactive
         * @param int $window Maximum time range of new data to scan (in 
seconds)
         * @return int|bool UNIX timestamp the cache is now up-to-date as of 
(false on error)
         */
-       protected static function doQueryCacheUpdate( DatabaseBase $dbw, $days, 
$window ) {
+       protected static function doQueryCacheUpdate( IDatabase $dbw, $days, 
$window ) {
                $dbw->startAtomic( __METHOD__ );
 
@@ -314,10 +314,10 @@
 
        /**
-        * @param DatabaseBase $dbw Passed in from updateSpecialPages.php
+        * @param IDatabase $dbw Passed in from updateSpecialPages.php
         * @return void
         */
                $lockKey = wfWikiID() . '-activeusers';
-- 
To view, visit https://gerrit.wikimedia.org/r/176981
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: Id945aaabbf5b467106676ea9f3eab3a6161c7f3d
Gerrit-PatchSet: 2
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: Aaron Schulz <[email protected]>
Gerrit-Reviewer: Chad <[email protected]>
Gerrit-Reviewer: KartikMistry <[email protected]>
Gerrit-Reviewer: TTO <[email protected]>
Gerrit-Reviewer: jenkins-bot <>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to